@@ -120,7 +120,8 @@ def num_threads():
     return 8
 
 def info(msg):
-    print(__name__ + '[' + str(os.getpid()) + ']' + msg)
+    now = datetime.now()
+    print(__name__ + '[' + str(os.getpid()) + '][' + now.strftime('%Y-%m-%d %H:%M:%S') + ']' + msg)
 
 def s3downloader(write_pipe, read_pipe, endpoint, glb):
     # info('s3downloader: started. endpoint=' + endpoint)
@@ -135,8 +136,9 @@ def s3downloader(write_pipe, read_pipe, endpoint, glb):
         if (op == 'download'):
             bucketname = read_pipe.recv()
             filename = read_pipe.recv()
-            # info('s3downloader: downloading ' + filename + ' from ' + bucketname)
+            # info('s3downloader: starting download of ' + filename + ' from ' + bucketname)
             obj = client.get_object(Bucket=bucketname, Key=filename)
+            # info('s3downloader: finished download of ' + filename + ' from ' + bucketname)
             strbody = obj['Body']
             datetime = obj['LastModified']
             bts = strbody.read()
@@ -145,7 +147,6 @@ def s3downloader(write_pipe, read_pipe, endpoint, glb):
                 write_pipe.send(key)
                 write_pipe.send(bts)
             else:
-                # info("Executing infin_transform_one_object for " + filename)
                 try:
                     namespaced_infin_transform_one_object(bucketname, filename, bts)
                 except Exception as e:
@@ -173,12 +174,13 @@ def s3downloader_by_dir(write_pipe, read_pipe, endpoint, glb):
             bucketname = read_pipe.recv()
             parentdir = read_pipe.recv()
             filename = read_pipe.recv()
-            info('s3downloader_by_dir: downloading ' + filename + ' from ' + bucketname + ' parent=' + parentdir)
+            # info('s3downloader_by_dir: starting download ' + filename + ' from ' + bucketname + ' parent=' + parentdir)
             if (parentdir == ''):
                 full_object_key = filename
             else:
                 full_object_key = parentdir + sep + filename
             obj = client.get_object(Bucket=bucketname, Key=full_object_key)
+            # info('s3downloader_by_dir: finished download ' + filename + ' from ' + bucketname + ' parent=' + parentdir)
             strbody = obj['Body']
             datetime = obj['LastModified']
             bts = strbody.read()
@@ -187,7 +189,7 @@ def s3downloader_by_dir(write_pipe, read_pipe, endpoint, glb):
                 write_pipe.send(key)
                 write_pipe.send(bts)
             else:
-                # info("Executing infin_transform_one_object for " + filename)
+                # info("s3downloader_by_dir: Executing infin_transform_one_object for " + filename)
                 try:
                     namespaced_infin_transform_one_object(bucketname, parentdir, filename, bts)
                 except Exception as e:
@@ -195,6 +197,7 @@ def s3downloader_by_dir(write_pipe, read_pipe, endpoint, glb):
                     info("Error executing infin_transform_one_object: " + status_str)
                 else:
                     status_str = 'Success'
+                # info("s3downloader_by_dir: Finshed infin_transform_one_object for " + filename)
                 write_pipe.send(key)
                 write_pipe.send(status_str)
         elif (op == 'quit'):
@@ -230,9 +233,17 @@ def load_one_csv_from_bytearray(bts):
     sio = StringIO(s)
     return pd.read_csv(sio)
 
+def download_objects(endpoint, bucketname, array_of_files, is_csv, glb):
+    try:
+        start_run()
+        objects = download_objects_inner(endpoint, bucketname, array_of_files, is_csv, None)
+    finally:
+        end_run()
+
 # returns a pandas DataFrame with index 'YY-MM-dd HH:MM:SS bucketname/filename'
 # and one column named RawBytes that contains the raw bytes from the object
-def download_objects(endpoint, bucketname, array_of_files, is_csv, glb):
+# This inner method is called after the outer method wraps in mlflow start_run
+def download_objects_inner(endpoint, bucketname, array_of_files, is_csv, glb):
     log_param("object_count", len(array_of_files))
 
     filebytes = []
@@ -428,7 +439,7 @@ def actually_run_transformation(client, endpoint, cache_path, is_pandas_df, buck
     print('Total Number Of Objects: ' + str(len(array_of_files)))
     try:
         start_run()
-        objects = download_objects(endpoint, bucketname, array_of_files, is_csv, None)
+        objects = download_objects_inner(endpoint, bucketname, array_of_files, is_csv, None)
     finally:
         end_run()
 
@@ -477,7 +488,6 @@ def actually_run_transformation(client, endpoint, cache_path, is_pandas_df, buck
 
 def read_raw_and_xform_to_pd(time_spec, service_name, bucketname, prefix_in, is_csv, xformname):
     endpoint = "https://" + time_spec + ".s3proxy." + service_name + ".com:443/";
-    print('endpoint=' + endpoint)
     session = boto3.session.Session(profile_name='infinstor')
     client = session.client('s3', endpoint_url=endpoint)
 
@@ -499,7 +509,6 @@ def read_raw_and_xform_to_pd(time_spec, service_name, bucketname, prefix_in, is_
 
 def read_raw_and_xform_to_ds(time_spec, service_name, bucketname, prefix_in, is_csv, xformname):
     endpoint = "https://" + time_spec + ".s3proxy." + service_name + ".com:443/";
-    print('endpoint=' + endpoint)
     session = boto3.session.Session(profile_name='infinstor')
     client = session.client('s3', endpoint_url=endpoint)
 
@@ -530,7 +539,6 @@ def run_xform_periodically(seconds, service_name, bucketname, prefix_in, xformna
 def read_raw_and_xform_one_object(time_spec, service_name, bucketname,\
         prefix_in, xformname):
     endpoint = "https://" + time_spec + ".s3proxy." + service_name + ".com:443/";
-    print('endpoint=' + endpoint)
     session = boto3.session.Session(profile_name='infinstor')
     client = session.client('s3', endpoint_url=endpoint)
 
@@ -589,7 +597,7 @@ def look_for_transform(transform_string, transform_symbol):
 
 def run_transform_inline(time_spec, service_name, bucketname, prefix_in, xformname):
     endpoint = "https://" + time_spec + ".s3proxy." + service_name + ".com:443/";
-    print('endpoint=' + endpoint)
+    print('infinstor proxy endpoint=' + endpoint)
     session = boto3.session.Session(profile_name='infinstor')
     client = session.client('s3', endpoint_url=endpoint)
 
